@@ -192,7 +192,7 @@ def delete_items_by_hashkey(dynamodbTableRes,hashkey):
     if hashKeyName is not None:
         KeyConditionExpression = Key(hashKeyName).eq(hashkey)
         # Get all the items corresponding to the hashkey
-        result = get_records_by_key_condition(tablename = "",KeyConditionExpression= KeyConditionExpression,dynamodbTableRes = table)
+        result = get_records_by_key_condition(tablename = "",KeyConditionExpression= KeyConditionExpression,dynamodbTableRes = dynamodbTableRes)
 
 
 
